@@ -1,15 +1,8 @@
 
 fn main() {
-
-    // Skip linking on docs.rs: https://docs.rs/about/builds#detecting-docsrs
-    let building_docs = std::env::var("DOCS_RS").is_ok();
-    if building_docs {
-        return;
-    };
-
     let dst = cmake::Config::new("ptex-c").build();
     println!("cargo:rustc-link-search=native={}", dst.display());
-    println!("cargo:rustc-link-lib=dylib=ptex-c-0_0");
+    println!("cargo:rustc-link-lib=dylib=ptex-c-2_4");
 
     let out_dir = std::env::var("OUT_DIR").unwrap();
     let output = std::process::Command::new("python")
@@ -26,8 +19,9 @@ fn main() {
         panic!("failed");
     }
 
-    println!("cargo:rustc-link-search=native=ptex/dist/lib64");
-    println!("cargo:rustc-link-search=native=ptex/dist/lib");
+
+    println!("cargo:rustc-link-search=native=../ptex/dist/lib64");
+    println!("cargo:rustc-link-search=native=../ptex/dist/lib");
     println!("cargo:rustc-link-lib=dylib=Ptex");
 
 
